==> haskell-validation-selective-0.1.0.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validation-selective
version:              0.1.0.1
visibility:           public
id:                   validation-selective-0.1.0.1-HUOHM8jiEwDL50yWU1tM1V
key:                  validation-selective-0.1.0.1-HUOHM8jiEwDL50yWU1tM1V
license:              MPL-2.0
copyright:            2020-2021 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  d902b6c440334013301d14db4e0110d0
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.0.1/site-local/validation-selective-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/validation-selective-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/validation-selective-0.1.0.1

hs-libraries:         HSvalidation-selective-0.1.0.1-HUOHM8jiEwDL50yWU1tM1V
depends:
    base-4.15.0.0 deepseq-1.4.5.0
    selective-0.4.2-EAAB6cUVlfZ2YG0ybMPaVr

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validation-selective-0.1.0.2-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validation-selective
version:              0.1.0.2
visibility:           public
id:                   validation-selective-0.1.0.2-HogEZr0KPn8ccX7f78kLN
key:                  validation-selective-0.1.0.2-HogEZr0KPn8ccX7f78kLN
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  449093f52a99a2bf368f365c23d450f5
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.0.2/site-local/validation-selective-0.1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/validation-selective-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.1.0.2-HogEZr0KPn8ccX7f78kLN
depends:
    base-4.15.1.0 deepseq-1.4.5.0 selective-0.5-I6hdHz9WJ4CIfjs9hWjUdm

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
